@@ -15,7 +15,9 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "kdecompat.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 // ----------------------------------------------------------------------------
 // QT Includes
