@@ -19,10 +19,6 @@
 #ifndef MYMONEYSCHEDULED_H
 #define MYMONEYSCHEDULED_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -34,10 +30,10 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include "mymoneytransaction.h"
-#include "mymoneyaccount.h"
 #include <kmymoney/export.h>
+#include <kmymoney/mymoneyaccount.h>
 #include <kmymoney/mymoneyobject.h>
+#include <kmymoney/mymoneytransaction.h>
 
 class MyMoneyStorageANON;
 
