@@ -20,6 +20,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -37,19 +41,19 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
-#include <khtmlview.h>
-#include <kconfig.h>
+#include <tdehtmlview.h>
+#include <tdeconfig.h>
 #include <kstdaction.h>
-#include <kmainwindow.h>
-#include <kactioncollection.h>
-#include <kapplication.h>
-#include <kmessagebox.h>
+#include <tdemainwindow.h>
+#include <tdeactioncollection.h>
+#include <tdeapplication.h>
+#include <tdemessagebox.h>
 #include <kdebug.h>
 #include <kmdcodec.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <kiconloader.h>
 
 // ----------------------------------------------------------------------------
@@ -114,7 +118,7 @@ KHomeView::KHomeView(TQWidget *parent, const char *name ) :
   m_showAllSchedules(false),
   m_needReload(true)
 {
-  m_part = new KHTMLPart(this, "htmlpart_km2");
+  m_part = new TDEHTMLPart(this, "htmlpart_km2");
   addWidget(m_part->view());
 
   m_filename = KMyMoneyUtils::findResource("appdata", TQString("html/home%1.html"));
@@ -181,20 +185,20 @@ void KHomeView::loadView(void)
     DOM::Element e = m_part->document().getElementById("test");
     if ( e.isNull() )
     {
-      qDebug("Element id=test not found");
+      tqDebug("Element id=test not found");
     }
     else
     {
-      qDebug("Element id=test found!");
+      tqDebug("Element id=test found!");
       TQString tagname = e.tagName().string();
-      qDebug("%s",tagname.latin1());
-      qDebug("%s id=%s",e.tagName().string().latin1(),e.getAttribute("id").string().latin1());
+      tqDebug(tagname);
+      tqDebug(TQString("%1 id=%2").arg(e.tagName().string()).arg(e.getAttribute("id").string()));
 
       // Find the character data node
       DOM::Node n = e.firstChild();
       while (!n.isNull())
       {
-        qDebug("Child type %u",static_cast<unsigned>(n.nodeType()));
+        tqDebug("Child type %u",static_cast<unsigned>(n.nodeType()));
         if ( n.nodeType() == DOM::Node::TEXT_NODE )
         {
           DOM::Text t = n;
@@ -204,7 +208,7 @@ void KHomeView::loadView(void)
           m_part->document().importNode(e,true);
           m_part->document().updateRendering();
 
-          qDebug("Data is now %s",t.data().string().latin1());
+          tqDebug(TQString("Data is now %1").arg(t.data().string()));
         }
         n = n.nextSibling();
       }
@@ -214,7 +218,7 @@ void KHomeView::loadView(void)
     //clear the forecast flag so it will be reloaded
     m_forecast.setForecastDone(false);
 
-    TQString filename = KGlobal::dirs()->findResource("appdata", "html/kmymoney2.css");
+    TQString filename = TDEGlobal::dirs()->findResource("appdata", "html/kmymoney2.css");
     TQString header = TQString("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\">\n<html><head><link rel=\"stylesheet\" type=\"text/css\" href=\"%1\">\n").arg(filename);
 
     header += KMyMoneyUtils::variableCSS();
@@ -322,7 +326,7 @@ void KHomeView::showNetWorthGraph(void)
   chartWidget->params()->setLineMarker(false);
   chartWidget->params()->setLegendPosition(KDChartParams::NoLegend);
   chartWidget->params()->setLineWidth(2);
-  chartWidget->params()->setDataColor(0, KGlobalSettings::textColor());
+  chartWidget->params()->setDataColor(0, TDEGlobalSettings::textColor());
 
     // draw future values in a different line style
   KDChartPropertySet propSetFutureValue("future value", KMM_KDCHART_PROPSET_NORMAL_DATA);
@@ -350,7 +354,7 @@ void KHomeView::showNetWorthGraph(void)
   }
 
   TQPixmap pm(chartWidget->width(), chartWidget->height());
-  pm.fill(KGlobalSettings::baseColor());
+  pm.fill(TDEGlobalSettings::baseColor());
   TQPainter p(&pm);
   chartWidget->paintTo(p);
 
@@ -632,7 +636,7 @@ void KHomeView::showPaymentEntry(const MyMoneySchedule& sched, int cnt)
 
   try {
     MyMoneyAccount acc = sched.account();
-    if(acc.id()) {
+    if(!acc.id().isEmpty()) {
       MyMoneyTransaction t = sched.transaction();
       // only show the entry, if it is still active
       // FIXME clean old code
@@ -641,12 +645,12 @@ void KHomeView::showPaymentEntry(const MyMoneySchedule& sched, int cnt)
         MyMoneySplit sp = t.splitByAccount(acc.id(), true);
 
         TQString pathEnter, pathSkip;
-        KGlobal::iconLoader()->loadIcon("key_enter", KIcon::Small, KIcon::SizeSmall, KIcon::DefaultState, &pathEnter);
-        KGlobal::iconLoader()->loadIcon("player_fwd", KIcon::Small, KIcon::SizeSmall, KIcon::DefaultState, &pathSkip);
+        TDEGlobal::iconLoader()->loadIcon("key_enter", TDEIcon::Small, TDEIcon::SizeSmall, TDEIcon::DefaultState, &pathEnter);
+        TDEGlobal::iconLoader()->loadIcon("media-seek-forward", TDEIcon::Small, TDEIcon::SizeSmall, TDEIcon::DefaultState, &pathSkip);
 
         //show payment date
         tmp = TQString("<td>") +
-          KGlobal::locale()->formatDate(sched.adjustedNextDueDate(), true) +
+          TDEGlobal::locale()->formatDate(sched.adjustedNextDueDate(), true) +
           "</td><td>";
         if(pathEnter.length() > 0)
           tmp += link(VIEW_SCHEDULE, TQString("?id=%1&mode=enter").arg(sched.id()), i18n("Enter schedule")) + TQString("<img src=\"file://%1\" border=\"0\"></a>").arg(pathEnter) + linkend();
@@ -682,12 +686,12 @@ void KHomeView::showPaymentEntry(const MyMoneySchedule& sched, int cnt)
         tmp += showColoredAmount(balance, balanceAfter.isNegative());
         tmp += "</td>";
 
-        // qDebug("paymentEntry = '%s'", tmp.latin1());
+        // tqDebug(TQString("paymentEntry = '%1'").arg(tmp));
         m_part->write(tmp);
       }
     }
   } catch(MyMoneyException* e) {
-    qDebug("Unable to display schedule entry: %s", e->what().data());
+    tqDebug(TQString("Unable to display schedule entry: %1").arg(e->what()));
     delete e;
   }
 }
@@ -868,7 +872,7 @@ void KHomeView::showAccountEntry(const MyMoneyAccount& acc, const MyMoneyMoney&
       tmp += TQString("<td class=\"right\">%1</td>").arg(showColoredAmount(amountToMinBal, valueToMinBal.isNegative()));
     }
   }
-  // qDebug("accountEntry = '%s'", tmp.latin1());
+  // tqDebug(TQString("accountEntry = '%1'").arg(tmp));
   m_part->write(tmp);
 }
 
@@ -893,7 +897,7 @@ MyMoneyMoney KHomeView::investmentBalance(const MyMoneyAccount& acc)
       val = val.convert(acc.fraction());
       value += val;
     } catch(MyMoneyException* e) {
-      qWarning("%s", (TQString("cannot convert stock balance of %1 to base currency: %2").arg(stock.name(), e->what())).data());
+      tqWarning(TQString("cannot convert stock balance of %1 to base currency: %2").arg(stock.name(), e->what()));
       delete e;
     }
   }
@@ -1116,11 +1120,11 @@ void KHomeView::slotOpenURL(const KURL &url, const KParts::URLArgs& /* args */)
 
   if ( protocol == "http" )
   {
-    KApplication::kApplication()->invokeBrowser(url.prettyURL());
+    TDEApplication::kApplication()->invokeBrowser(url.prettyURL());
   }
   else if ( protocol == "mailto" )
   {
-    KApplication::kApplication()->invokeMailer(url);
+    TDEApplication::kApplication()->invokeMailer(url);
   }
   else
   {
@@ -1130,20 +1134,20 @@ void KHomeView::slotOpenURL(const KURL &url, const KParts::URLArgs& /* args */)
     } else if(view == VIEW_SCHEDULE) {
       if(mode == "enter") {
         emit scheduleSelected(id);
-        KMainWindow* mw = dynamic_cast<KMainWindow*>(tqApp->mainWidget());
-        Q_CHECK_PTR(mw);
+        TDEMainWindow* mw = dynamic_cast<TDEMainWindow*>(tqApp->mainWidget());
+        TQ_CHECK_PTR(mw);
         TQTimer::singleShot(0, mw->actionCollection()->action("schedule_enter"), TQT_SLOT(activate()));
 
       } else if(mode == "edit") {
         emit scheduleSelected(id);
-        KMainWindow* mw = dynamic_cast<KMainWindow*>(tqApp->mainWidget());
-        Q_CHECK_PTR(mw);
+        TDEMainWindow* mw = dynamic_cast<TDEMainWindow*>(tqApp->mainWidget());
+        TQ_CHECK_PTR(mw);
         TQTimer::singleShot(0, mw->actionCollection()->action("schedule_edit"), TQT_SLOT(activate()));
 
       } else if(mode == "skip") {
         emit scheduleSelected(id);
-        KMainWindow* mw = dynamic_cast<KMainWindow*>(tqApp->mainWidget());
-        Q_CHECK_PTR(mw);
+        TDEMainWindow* mw = dynamic_cast<TDEMainWindow*>(tqApp->mainWidget());
+        TQ_CHECK_PTR(mw);
         TQTimer::singleShot(0, mw->actionCollection()->action("schedule_skip"), TQT_SLOT(activate()));
 
       } else if(mode == "full") {
@@ -1159,8 +1163,8 @@ void KHomeView::slotOpenURL(const KURL &url, const KParts::URLArgs& /* args */)
       emit reportSelected(id);
 
     } else if(view == VIEW_WELCOME) {
-      KMainWindow* mw = dynamic_cast<KMainWindow*>(tqApp->mainWidget());
-      Q_CHECK_PTR(mw);
+      TDEMainWindow* mw = dynamic_cast<TDEMainWindow*>(tqApp->mainWidget());
+      TQ_CHECK_PTR(mw);
       if ( mode == "whatsnew" )
       {
         TQString fname = KMyMoneyUtils::findResource("appdata",TQString("html/whats_new%1.html"));
@@ -1171,9 +1175,9 @@ void KHomeView::slotOpenURL(const KURL &url, const KParts::URLArgs& /* args */)
         m_part->openURL(m_filename);
 
     } else if(view == "action") {
-      KMainWindow* mw = dynamic_cast<KMainWindow*>(tqApp->mainWidget());
-      Q_CHECK_PTR(mw);
-      TQTimer::singleShot(0, mw->actionCollection()->action( id ), TQT_SLOT(activate()));
+      TDEMainWindow* mw = dynamic_cast<TDEMainWindow*>(tqApp->mainWidget());
+      TQ_CHECK_PTR(mw);
+      TQTimer::singleShot(0, mw->actionCollection()->action(id.utf8()), TQT_SLOT(activate()));
 
     } else if(view == VIEW_HOME) {
       TQValueList<MyMoneyAccount> list;
@@ -1184,7 +1188,7 @@ void KHomeView::slotOpenURL(const KURL &url, const KParts::URLArgs& /* args */)
       loadView();
 
     } else {
-      qDebug("Unknown view '%s' in KHomeView::slotOpenURL()", view.latin1());
+      tqDebug(TQString("Unknown view '%1' in KHomeView::slotOpenURL()").arg(view));
     }
   }
 }
@@ -1649,7 +1653,7 @@ void KHomeView::showCashFlowSummary()
     }
 
     MyMoneyAccount acc = (*sched_it).account();
-    if(acc.id()) {
+    if(!acc.id().isEmpty()) {
       MyMoneyTransaction transaction = (*sched_it).transaction();
       // only show the entry, if it is still active
 
