@@ -40,7 +40,7 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include "kdecompat.h"
+#include <tdeversion.h>
 
 #include <tdefiledialog.h>
 #include <tdeglobal.h>
@@ -559,7 +559,7 @@ bool KMyMoneyView::readFile(const KURL& url)
 #else
   if(url.isMalformed()) {
 #endif
-    tqDebug("Invalid URL '%s'", url.url().latin1());
+    tqDebug(TQString("Invalid URL '%1'").arg(url.url()));
     return false;
   }
 
@@ -911,7 +911,7 @@ bool KMyMoneyView::initializeStorage()
       // Check if we have to modify the file before we allow to work with it
       IMyMoneyStorage* s = MyMoneyFile::instance()->storage();
       while (s->fileFixVersion() < s->currentFixVersion()) {
-        tqDebug("%s", (TQString("testing fileFixVersion %1 < %2").arg(s->fileFixVersion()).arg(s->currentFixVersion())).data());
+        tqDebug(TQString("testing fileFixVersion %1 < %2").arg(s->fileFixVersion()).arg(s->currentFixVersion()));
         switch (s->fileFixVersion()) {
           case 0:
             fixFile_0();
@@ -1150,7 +1150,7 @@ bool KMyMoneyView::saveFile(const KURL& url, const TQString& keyList)
           throw new MYMONEYEXCEPTION(i18n("Unable to write changes to '%1'").arg(filename));
         }
       }
-      chown(filename, static_cast<uid_t>(-1), gid);
+      chown(filename.local8Bit(), static_cast<uid_t>(-1), gid);
     } else {
       KTempFile tmpfile;
       saveToLocalFile(tmpfile.file(), pWriter, plaintext, keyList);
@@ -1308,7 +1308,7 @@ void KMyMoneyView::selectBaseCurrency(void)
           file->modifyAccount(*it);
           ft.commit();
         } catch(MyMoneyException *e) {
-          tqDebug("Unable to setup base currency in account %s (%s): %s", (*it).name().latin1(), (*it).id().data(), e->what().latin1());
+          tqDebug(TQString("Unable to setup base currency in account %1 (%2): %3").arg((*it).name()).arg((*it).id()).arg(e->what()));
           delete e;
         }
       }
@@ -1336,7 +1336,7 @@ void KMyMoneyView::loadDefaultCurrency(const MyMoneySecurity& currency, const bo
       }
       ft.commit();
     } catch (MyMoneyException* e) {
-      tqDebug("Error %s loading default currency", e->what().data());
+      tqDebug(TQString("Error %1 loading default currency").arg(e->what()));
       delete e;
     }
   }
@@ -1536,7 +1536,7 @@ void KMyMoneyView::loadAncientCurrency(const TQString& id, const TQString& name,
       }
       ft.commit();
     } catch(MyMoneyException *e) {
-      tqDebug("Error loading currency: %s", e->what().data());
+      tqDebug(TQString("Error loading currency: %1").arg(e->what()));
       delete e;
     }
   }
@@ -1866,7 +1866,7 @@ void KMyMoneyView::fixSchedule_0(MyMoneySchedule sched)
       MyMoneyFile::instance()->modifySchedule(sched);
     }
   } catch(MyMoneyException *e) {
-    tqWarning("Unable to update broken schedule: %s", e->what().latin1());
+    tqWarning(TQString("Unable to update broken schedule: %1").arg(e->what()));
     delete e;
   }
 }
@@ -2082,7 +2082,7 @@ void KMyMoneyView::fixTransactions_0(void)
         file->modifyTransaction(*it_t);
       }
       splits = (*it_t).splits();    // update local copy
-      tqDebug("Fixed credit card assignment in %s", (*it_t).id().data());
+      tqDebug(TQString("Fixed credit card assignment in %1").arg((*it_t).id()));
     }
 #endif
 
@@ -2104,7 +2104,7 @@ void KMyMoneyView::fixTransactions_0(void)
           (*it_s).setAction(MyMoneySplit::ActionInterest);
           (*it_t).modifySplit(*it_s);
           file->modifyTransaction(*it_t);
-          tqDebug("Fixed interest action in %s", (*it_t).id().data());
+          tqDebug(TQString("Fixed interest action in %1").arg((*it_t).id()));
         }
       // if it does not reference an interest account, it must not be
       // of type ActionInterest
@@ -2114,7 +2114,7 @@ void KMyMoneyView::fixTransactions_0(void)
           (*it_s).setAction(defaultAction);
           (*it_t).modifySplit(*it_s);
           file->modifyTransaction(*it_t);
-          tqDebug("Fixed interest action in %s", (*it_t).id().data());
+          tqDebug(TQString("Fixed interest action in %1").arg((*it_t).id()));
         }
       }
 
@@ -2134,14 +2134,14 @@ void KMyMoneyView::fixTransactions_0(void)
         try {
           int fract = splitAccount.fraction();
           if((*it_s).shares() != (*it_s).shares().convert(fract)) {
-            tqDebug("adjusting fraction in %s,%s", (*it_t).id().data(), (*it_s).id().data());
+            tqDebug(TQString("adjusting fraction in %1,%2").arg((*it_t).id()).arg((*it_s).id()));
             (*it_s).setShares((*it_s).shares().convert(fract));
             (*it_s).setValue((*it_s).value().convert(fract));
             (*it_t).modifySplit(*it_s);
             file->modifyTransaction(*it_t);
           }
         } catch(MyMoneyException* e) {
-          tqDebug("Missing security '%s', split not altered", splitAccount.currencyId().data());
+          tqDebug(TQString("Missing security '%1', split not altered").arg(splitAccount.currencyId()));
           delete e;
         }
       }
@@ -2164,7 +2164,7 @@ void KMyMoneyView::fixTransactions_0(void)
 
 void KMyMoneyView::fixDuplicateAccounts_0(MyMoneyTransaction& t)
 {
-  tqDebug("Duplicate account in transaction %s", t.id().data());
+  tqDebug(TQString("Duplicate account in transaction %1").arg(t.id()));
 }
 
 void KMyMoneyView::slotPrintView(void)
