@@ -25,8 +25,6 @@
 #include <config.h>
 #endif
 
-#include "kdecompat.h"
-
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -551,10 +549,10 @@ void KReportsView::slotOpenURL(const KURL &url, const KParts::URLArgs& /* args *
     else if ( command == "delete" )
       slotDelete();
     else
-      tqDebug("Unknown command '%s' in KReportsView::slotOpenURL()", static_cast<const char*>(command));
+      tqDebug(TQString("Unknown command '%1' in KReportsView::slotOpenURL()").arg(command));
 
   } else {
-    tqDebug("Unknown view '%s' in KReportsView::slotOpenURL()", view.latin1());
+    tqDebug(TQString("Unknown view '%1' in KReportsView::slotOpenURL()").arg(view));
   }
 }
 
