@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <typeinfo>
 
 // ----------------------------------------------------------------------------
@@ -184,7 +188,7 @@ bool ItemPtrVector::item_cmp(RegisterItem* i1, RegisterItem* i2)
         break;
 
       case EntryOrderSort:
-        rc = qstrcmp(i1->sortEntryOrder(), i2->sortEntryOrder());
+        rc = TQString::compare(i1->sortEntryOrder(), i2->sortEntryOrder());
         break;
 
       case TypeSort:
@@ -214,7 +218,7 @@ bool ItemPtrVector::item_cmp(RegisterItem* i1, RegisterItem* i2)
   }
 
   if(rc == 0) {
-    rc = qstrcmp(i1->sortEntryOrder(), i2->sortEntryOrder());
+    rc = TQString::compare(i1->sortEntryOrder(), i2->sortEntryOrder());
   }
 
   return rc < 0;
@@ -633,7 +637,7 @@ void Register::dropEvent(TQDropEvent* event)
       tqDebug("Drop was ok");
       KURL::List urls;
       KURLDrag::decode(event, urls);
-      tqDebug("List is '%s'", urls.toStringList().join(";").data());
+      tqDebug(TQString("List is '%s'").arg(urls.toStringList().join(";")));
       event->accept();
     }
   }
@@ -667,7 +671,7 @@ void Register::slotAutoColumnSizing(int section)
       }
       size += TQString("%1").arg((columnWidth(i) * 100) / w);
     }
-    tqDebug("size = %s", size.data());
+    tqDebug(TQString("size = %1").arg(size));
     m_account.setValue("kmm-ledger-column-width", size);
   }
 #endif
@@ -1849,7 +1853,7 @@ void Register::slotEnsureItemVisible(void)
 TransactionSortField KMyMoneyRegister::textToSortOrder(const TQString& text)
 {
   for(int idx = 1; idx < static_cast<int>(MaxSortFields); ++idx) {
-    if(text == i18n(sortOrderText[idx])) {
+    if(text == i18n(sortOrderText[idx].utf8())) {
       return static_cast<TransactionSortField>(idx);
     }
   }
@@ -1860,7 +1864,7 @@ const TQString KMyMoneyRegister::sortOrderToText(TransactionSortField idx)
 {
   if(idx < PostDateSort || idx >= MaxSortFields)
     idx = UnknownSort;
-  return i18n(sortOrderText[idx]);
+  return i18n(sortOrderText[idx].utf8());
 }
 
 TQString Register::text(int /*row*/, int /*col*/) const
@@ -2434,5 +2438,3 @@ void Register::removeUnwantedGroupMarkers(void)
 
 
 #include "register.moc"
-
-// vim:cin:si:ai:et:ts=2:sw=2:
